aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/System
diff options
context:
space:
mode:
authorJoshua M. Boniface <joshua@boniface.me>2026-03-23 17:15:49 -0400
committerJoshua M. Boniface <joshua@boniface.me>2026-03-23 17:15:49 -0400
commit418beafebb49527974c5563907367e6b689352a3 (patch)
treecf5b94f097e3d315a5ce9ed4d3744e311ef80e42 /MediaBrowser.Model/System
parent434ebc8b110a2736c9be08360c17cf74e27803d1 (diff)
Update FolderStorageInfo record
Diffstat (limited to 'MediaBrowser.Model/System')
-rw-r--r--MediaBrowser.Model/System/FolderStorageInfo.cs11
1 files changed, 8 insertions, 3 deletions
diff --git a/MediaBrowser.Model/System/FolderStorageInfo.cs b/MediaBrowser.Model/System/FolderStorageInfo.cs
index 7b10e4ea58..66356c6c48 100644
--- a/MediaBrowser.Model/System/FolderStorageInfo.cs
+++ b/MediaBrowser.Model/System/FolderStorageInfo.cs
@@ -11,17 +11,22 @@ public record FolderStorageInfo
public required string Path { get; init; }
/// <summary>
- /// Gets the free space of the underlying storage device of the <see cref="Path"/>.
+ /// Gets the fully resolved path of the folder in question (interpolating any symlinks if present)
+ /// </summary>
+ public required string ResolvedPath { get; init; }
+
+ /// <summary>
+ /// Gets the free space of the underlying storage device of the <see cref="ResolvedPath"/>.
/// </summary>
public long FreeSpace { get; init; }
/// <summary>
/// Gets the used space of the underlying storage device of the <see cref="Path"/>.
/// </summary>
public long UsedSpace { get; init; }
/// <summary>
/// Gets the kind of storage device of the <see cref="Path"/>.
/// </summary>
public string? StorageType { get; init; }
@@ -11,17 +11,22 @@ public record FolderStorageInfo
public long FreeSpace { get; init; }
/// <summary>
- /// Gets the used space of the underlying storage device of the <see cref="Path"/>.
+ /// Gets the used space of the underlying storage device of the <see cref="ResolvedPath"/>.
/// </summary>
public long UsedSpace { get; init; }
@@ -11,17 +11,22 @@ public record FolderStorageInfo
public long UsedSpace { get; init; }
/// <summary>
- /// Gets the kind of storage device of the <see cref="Path"/>.
+ /// Gets the kind of storage device of the <see cref="ResolvedPath"/>.
/// </summary>
public string? StorageType { get; init; }